/**
 * This module represents the Gitlab CI [artifacts](https://docs.gitlab.com/ee/ci/yaml/#artifacts) keyword
 *
 * Simple example:
 *
 * ```ts
 * import { Artifact, ArtifactReport } from gcix
 *
 * const files = ["file1.txt", "file2.txt", "path/to/file3.txt"]
 *
 * const job1 = new Job({stage: "buildit", scripts: ["build my app"]})
 * job1.addArtifacts(new Artifacts({paths: files}))
 * ```
 */
import { IBase, OrderedStringSet, WhenStatement } from ".";
/**
 * @internal
 */
export interface RenderdArtifacts {
    readonly paths?: string[];
    readonly excludes?: string[];
    readonly expire_in?: string;
    readonly expose_as?: string;
    readonly name?: string;
    readonly public?: boolean;
    readonly untracked?: boolean;
    readonly when?: WhenStatement;
    readonly reports?: {
        [key: string]: string;
    };
}
/**
 * This interface represents the [artifacts:reports](https://docs.gitlab.com/ee/ci/yaml/#artifactsreports) types.
 */
export type ArtifactsReportType = "accessibility" | "api_fuzzing" | "browser_performance" | "coverage_report" | "codequality" | "container_scanning" | "coverage_fuzzing" | "cyclonedx" | "dast" | "dependency_scanning" | "dotenv" | "junit" | "license_scanning" | "load_performance" | "metrics" | "requirements" | "sast" | "secret_detection" | "terraform";
export interface ArtifactsReport {
    /**
     * https://docs.gitlab.com/ee/ci/yaml/artifacts_reports.html
     * ArtifactsReport type to use.
     */
    readonly reportType: ArtifactsReportType;
    /**
     * Relative path withing the project, where to find the generated report file
     */
    readonly file: string;
}
export interface ArtifactsProps {
    /**
     * Paths relative to project directory `$CI_PROJECT_DIR`, found files
     * will be used to create the artifacts.
     */
    readonly paths?: string[];
    /**
     * Paths that prevent files from being added to an artifacts archive.
     */
    readonly excludes?: string[];
    /**
     * How long the artifacts will be saved before it gets deleted.
     */
    readonly expireIn?: string;
    /**
     * Used to expose artifacts in merge requests.
     */
    readonly exposeAs?: string;
    /**
     * Name of the artifacts archive.
     * Internally defaults to {PredefinedVariables.ciJobName}-{PredefinedVariables.ciCommitRefSlug}.
     */
    readonly name?: string;
    /**
     * True makes artifacts public.
     */
    readonly public?: boolean;
    /**
     * Reports must be a valid dictionary, the key represents a ArtifactsReport
     * and the value must be a valid relativ file path to the reports file.
     */
    readonly reports?: ArtifactsReport[];
    /**
     * If true adds all untracked file to artifacts archive.
     */
    readonly untracked?: boolean;
    /**
     * When to upload artifacts, Only `on_success`, `on_failure` or `always` is allowed.
     */
    readonly when?: WhenStatement;
}
export interface IArtifacts extends IBase {
    readonly paths: string[];
    readonly excludes: string[];
    readonly expireIn?: string;
    readonly exposeAs?: string;
    readonly name?: string;
    readonly public?: boolean;
    readonly untracked?: boolean;
    readonly when?: WhenStatement;
    readonly reports?: ArtifactsReport[];
    addPaths(paths: string[]): void;
    addExcludes(excludes: string[]): void;
}
/**
 * This class represents the [artifacts](https://docs.gitlab.com/ee/ci/yaml/#artifacts) keyword.
 *
 * Gitlab CI documentation: _"Use artifacts to specify a list of files and
 * directories that are attached to the `gcix.Job` when it succeeds,
 * fails, or always. [...] by default, `gcix.Job`s in later stages
 * automatically download all the artifacts created by jobs in earlier stages.
 * You can control artifact download behavior in Job's with dependencies."_
 *
 * @raises Error if when is not `on_success`, `on_failure` or `always`.
 */
export declare class Artifacts implements IArtifacts {
    orderedPaths: OrderedStringSet;
    orderedExcludes: OrderedStringSet;
    readonly expireIn: string | undefined;
    readonly exposeAs: string | undefined;
    readonly name: string | undefined;
    readonly public: boolean | undefined;
    readonly untracked: boolean | undefined;
    readonly when: WhenStatement | undefined;
    readonly reports?: ArtifactsReport[];
    constructor(props: ArtifactsProps);
    get paths(): string[];
    get excludes(): string[];
    addPaths(paths: string[]): void;
    addExcludes(excludes: string[]): void;
    /**
     * @returns RenderdArtifacts
     */
    render(): any;
    isEqual(comparable: IBase): comparable is Artifacts;
}
