import { Job } from "../";
/**
 * Configuration properties for initializing a Bootstrap instance.
 */
export interface BootstrapProps {
    /**
     * The AWS account ID associated with the Bootstrap configuration.
     */
    readonly awsAccountId: string;
    /**
     * The AWS region in which the Bootstrap will be performed.
     */
    readonly awsRegion: string;
    /**
     * The name of the toolkit stack used for Bootstrap.
     */
    readonly toolkitStackName: string;
    /**
     * The qualifier applied to the Bootstrap.
     */
    readonly qualifier: string;
    /**
     * Optional resource tags that can be applied during Bootstrap.
     */
    readonly resourceTags?: {
        [key: string]: string;
    };
    /**
     * An optional name for the Bootstrap job.
     */
    readonly jobName?: string;
    /**
     * An optional stage for the Bootstrap job.
     */
    readonly jobStage?: string;
}
/**
 * Represents the interface that a Bootstrap instance adheres to.
 */
export interface IBootstrap {
    /**
     * The AWS account ID associated with the Bootstrap configuration.
     */
    awsAccountId: string;
    /**
     * The AWS region in which the Bootstrap will be performed.
     */
    awsRegion: string;
    /**
     * The name of the toolkit stack used for Bootstrap.
     */
    toolkitStackName: string;
    /**
     * The qualifier applied to the Bootstrap.
     */
    qualifier: string;
    /**
     * Optional resource tags that can be applied during Bootstrap.
     */
    resourceTags?: {
        [key: string]: string;
    };
    /**
     * The name of the Bootstrap job.
     */
    jobName: string;
    /**
     * The stage of the Bootstrap job.
     */
    jobStage: string;
}
/**
 * Creates an instance of Bootstrap.
 * @param props - Configuration properties for the Bootstrap job.
 */
export declare class Bootstrap extends Job implements IBootstrap {
    awsAccountId: string;
    awsRegion: string;
    toolkitStackName: string;
    qualifier: string;
    resourceTags?: {
        [key: string]: string;
    } | undefined;
    jobName: string;
    jobStage: string;
    constructor(props: BootstrapProps);
    render(): any;
}
/**
 * Configuration properties for initializing a Diff instance.
 */
export interface DiffProps {
    /**
     * An array of stack names for which to generate a diff.
     */
    readonly stacks: string[];
    /**
     * Optional diff options to customize the diff process.
     */
    readonly diffOptions?: string;
    /**
     * Optional context values to provide additional information for the diff.
     */
    readonly context?: Record<string, string>;
    /**
     * An optional name for the Diff job.
     */
    readonly jobName?: string;
    /**
     * An optional stage for the Diff job.
     */
    readonly jobStage?: string;
}
/**
 * Represents the interface that a Diff instance adheres to.
 */
export interface IDiff {
    /**
     * An array of stack names for which to generate a diff.
     */
    stacks: string[];
    /**
     * Optional diff options to customize the diff process.
     */
    diffOptions?: string;
    /**
     * Optional context values to provide additional information for the diff.
     */
    context?: Record<string, string>;
    /**
     * An optional name for the Diff job.
     */
    jobName?: string;
    /**
     * An optional stage for the Diff job.
     */
    jobStage?: string;
}
/**
 * A class that manages the configuration and rendering of a Diff job.
 * Inherits from the base Job class and implements the IDiff interface.
 */
export declare class Diff extends Job implements IDiff {
    stacks: string[];
    diffOptions?: string;
    context?: Record<string, string>;
    jobName?: string;
    jobStage?: string;
    /**
     * Creates an instance of Diff.
     * @param props - Configuration properties for the Diff job.
     */
    constructor(props: DiffProps);
    render(): any;
}
/**
 * Configuration properties for initializing a Deploy instance.
 */
export interface DeployProps {
    /**
     * An array of stack names to be deployed.
     */
    readonly stacks: string[];
    /**
     * Optional toolkit stack name used for deployment.
     */
    readonly toolkitStackName?: string;
    /**
     * Enable strict deployment mode.
     */
    readonly strict?: boolean;
    /**
     * Wait for stacks to complete deployment.
     */
    readonly waitForStack?: boolean;
    /**
     * AWS assume role for stack waiting.
     */
    readonly waitForStackAssumeRole?: string;
    /**
     * AWS account ID for stack waiting.
     */
    readonly waitForStackAccountId?: string;
    /**
     * Optional deployment options.
     */
    readonly deployOptions?: string;
    /**
     * Optional context values to provide additional information for deployment.
     */
    readonly context?: Record<string, string>;
    /**
     * An optional name for the Deploy job.
     */
    readonly jobName?: string;
    /**
     * An optional stage for the Deploy job.
     */
    readonly jobStage?: string;
}
/**
 * Represents the interface that a Deploy instance adheres to.
 */
export interface IDeploy {
    /**
     * An array of stack names to be deployed.
     */
    stacks: string[];
    /**
     * Optional toolkit stack name used for deployment.
     */
    toolkitStackName?: string;
    /**
     * Flag indicating if strict deployment mode is enabled.
     */
    strict: boolean;
    /**
     * Flag indicating if the deployment should wait for stack completion.
     */
    waitForStack: boolean;
    /**
     * AWS assume role for stack waiting.
     */
    waitForStackAssumeRole?: string;
    /**
     * AWS account ID for stack waiting.
     */
    waitForStackAccountId?: string;
    /**
     * Optional deployment options.
     */
    deployOptions?: string;
    /**
     * Optional context values to provide additional information for deployment.
     */
    context?: Record<string, string>;
    /**
     * An optional name for the Deploy job.
     */
    jobName?: string;
    /**
     * An optional stage for the Deploy job.
     */
    jobStage?: string;
}
/**
 * A class that manages the configuration and rendering of a Deploy job.
 * Inherits from the base Job class and implements the IDeploy interface.
 */
export declare class Deploy extends Job implements IDeploy {
    stacks: string[];
    toolkitStackName?: string;
    strict: boolean;
    waitForStack: boolean;
    waitForStackAssumeRole?: string;
    waitForStackAccountId?: string;
    context?: Record<string, string>;
    deployOptions?: string;
    jobName?: string;
    jobStage?: string;
    /**
     * Creates an instance of Deploy.
     * @param props - Configuration properties for the Deploy job.
     */
    constructor(props: DeployProps);
    /**
     * Renders the Deploy job's configuration and scripts.
     * @returns The rendered configuration and scripts.
     */
    render(): any;
}
