/**
 * A JobCollection serves as a container for multiple `gcix.Job`s and/or other
 * `gcix.JobCollection`s, allowing you to group them together.
 *
 * While the concept of a JobCollection is not an official representation of a
 * GitLab CI keyword, it is a powerful extension of the GitLab CI core
 * functionality and a fundamental building block of the `gcix` module.
 *
 * A JobCollection offers a similar interface to `gcix.Job`s, allowing you to
 * modify all Jobs and child JobCollections contained within it. For example,
 * instead of calling `addTags()` on individual Jobs, you can call `addTags()`
 * on the JobCollection that contains those Jobs. This will apply the tags to
 * all Jobs in the JobCollection and recursively to all Jobs within child
 * JobCollections.
 *
 * It's important to note that JobCollections must be added to a
 * `gcix.Pipeline`, either directly or as part of another JobCollection.
 * JobCollections are not meant to be used as throwaway configuration
 * containers for a group of Jobs. When you add a Job to a JobCollection, a
 * copy of that Job is created and indirectly added to the Pipeline by the
 * JobCollection. If you don't add the JobCollection to a Pipeline, its Jobs
 * will not be added either. This can lead to broken dependencies if other
 * parts of the Pipeline rely on those Jobs.
 *
 * To avoid conflicts between Jobs, it's recommended to set the name and/or
 * stage when adding a Job (or child JobCollection) to a JobCollection.
 * The JobCollection will incorporate the name and stage values into the ones
 * of the Job when rendering the pipeline. If you don't set these identifiers
 * or set the same name/stage for multiple jobs and JobCollections, it can
 * result in multiple Jobs with the same name in the pipeline.
 * The gcix module will raise an Error in such cases to prevent unexpected
 * pipeline behavior. You can find more information in the
 * "Stages allow reuse of jobs and JobCollections" chapter of the user
 * documentation.
 */
import { IBase, OrderedStringSet, Variables, Artifacts, Cache, Image, Job, Need, Rule } from ".";
export interface ChildDict {
    readonly child: Job | JobCollection;
    readonly stage?: string;
    readonly name?: string;
}
export interface AddChildrenProps {
    readonly jobsOrJobCollections: (Job | JobCollection)[];
    readonly stage?: string;
    readonly name?: string;
}
export interface IJobCollectionBase extends IBase {
    /**
     * @description Adds one or more [variables](https://docs.gitlab.com/ee/ci/yaml/README.html#variables), to the job.
     */
    addVariables(variables: Variables): JobCollection;
    /**
     * @description Sets the [cache](https://docs.gitlab.com/ee/ci/yaml/README.html#cache) keyword of the Job.
     *
     * !! Any previous values will be overwritten.
     */
    assignCache(cache: Cache): JobCollection;
    /**
     * @description Sets the [artifacts](https://docs.gitlab.com/ee/ci/yaml/README.html#artifacts) keyword of the Job.
     * !! Any previous values will be overwritten.
     */
    assignArtifacts(artifacts: Artifacts): JobCollection;
    /**
     * @description Adds one or more [tags](https://docs.gitlab.com/ee/ci/yaml/README.html#tags) to the job.
     */
    addTags(tags: string[]): JobCollection;
    /**
     * @description Appends one or more  [rule](https://docs.gitlab.com/ee/ci/yaml/README.html#rules)s rules to the job.
     */
    appendRules(rules: Rule[]): JobCollection;
    /**
     * @description Inserts one or more  [rule](https://docs.gitlab.com/ee/ci/yaml/README.html#rules)s before the current rules of the job.
     */
    prependRules(rules: Rule[]): JobCollection;
    /**
     * @description Add one or more [dependencies](https://docs.gitlab.com/ee/ci/yaml/README.html#dependencies) to the job.
     */
    addDependencies(dependencies: (Need | Job | JobCollection)[]): JobCollection;
    /**
     * @description Add one or more [needs](https://docs.gitlab.com/ee/ci/yaml/README.html#needs) to the job.
     */
    addNeeds(needs: (Need | Job | JobCollection)[]): JobCollection;
    /**
     * @description Inserts one or more [script](https://docs.gitlab.com/ee/ci/yaml/README.html#script)s before the current scripts.
     */
    prependScripts(scripts: string[]): JobCollection;
    /**
     * @description Adds one or more [script](https://docs.gitlab.com/ee/ci/yaml/README.html#script)s after the current scripts.
     */
    appendScripts(scripts: string[]): JobCollection;
    /**
     * Return all instance names from the given child.
     *
     * That means all combinations of the childs name and stage within this
     * JobCollection and all parent JobCollection's.
     */
    getAllInstanceNames(child?: Job | JobCollection): OrderedStringSet;
}
export interface IJobCollection extends IJobCollectionBase {
    parents: (Job | JobCollection)[];
    children: ChildDict[];
    allowFailureForInitialization?: string | boolean | number[];
    allowFailureForReplacement?: string | boolean | number[];
    variables?: Variables;
    variablesForInitialization?: Variables;
    variablesForReplacement?: Variables;
    cache?: Cache;
    cacheForInitialization?: Cache;
    artifacts?: Artifacts;
    artifactsForInitialization?: Artifacts;
    artifactsForReplacement?: Artifacts;
    orderedTags: OrderedStringSet;
    orderedTagsForInitialization: OrderedStringSet;
    orderedTagsForReplacement: OrderedStringSet;
    rulesToAppend?: Rule[];
    rulesToPrepend?: Rule[];
    rulesForInitialization?: Rule[];
    rulesForReplacement?: Rule[];
    dependencies?: (Job | JobCollection | Need)[];
    dependenciesForInitialization?: (Job | JobCollection | Need)[];
    dependenciesForReplacement?: (Job | JobCollection | Need)[];
    needs?: (Need | Job | JobCollection)[];
    needsForInitialization?: (Need | Job | JobCollection)[];
    needsForReplacement?: (Need | Job | JobCollection)[];
    scriptsToPrepend?: string[];
    scriptsToAppend?: string[];
    imageForInitialization?: Image | string;
    imageForReplacement?: Image | string;
    /**
     * Returns a list with populated copies of all nested jobs of this
     * JobCollection.
     *
     * Populated means, that all attributes of a Job which depends on its context
     * are resolved to their final values. The context is primarily the
     * JobCollection within the jobs resides but also dependencies to other
     * jobs and JobCollection's. Thus this JobCollection will apply its own
     * configuration, like variables to add, tags to set, etc., to all its jobs
     * and JobCollection's.
     *
     * Copies means what it says, that the returned job are not the same job
     * objects, originally added to this JobCollection, but copies of them.
     *
     * Nested means, that also jobs from JobCollection's within this
     * JobCollection, are returned, as well as jobs from JobCollection's within
     * JobCollection's within this JobCollection and so on.
     */
    readonly populatedJobs: Job[];
    /**
     * This property returns all Jobs from the last stage of this JobCollection.
     *
     * This is typically be requested from a job which has setup this
     * JobCollection as need, to determine all actual jobs of this JobCollection
     * as need.
     */
    readonly lastJobsExecuted: Job[];
    /**
     * @returns all jobs of this this JobCollection as well as jobs of
     * sub-JobCollection recursively.
     */
    readonly nestedJobs: Job[];
    /**
     * Add `gcix.Job`s or other `gcix.JobCollection`s to this JobCollection.
     *
     * Adding a child creates a copy of that child. You should provide a name or
     * stage when adding children, to make them different from other places
     * where they will be used.
     *
     * @returns JobCollection of the modified `JobCollection` object.
     */
    addChildren(props: AddChildrenProps): JobCollection;
    /**
     * Calling `gcix.Job.addVariables({...})` to all jobs within this
     * JobCollection that haven't been added variables before.
     * @param variables ???
     */
    initializeVariables(variables: Variables): JobCollection;
    /**
     * Calling `gcix.Job.addVariables({...})` to all jobs within this
     * JobCollection and overriding any previously added variables to that jobs.
     * @param variables ???
     */
    overrideVariables(variables: Variables): JobCollection;
    /**
     * Calling `gcix.Job.assigneCache()` to all jobs within this JobCollection
     * that haven't been set the cache before.
     * @param cache ???
     */
    initializeCache(cache: Cache): JobCollection;
    /**
     * Sets `gcix.Job.artifacts` to all jobs within this JobCollection that
     * haven't been set the artifacs before.
     * @param artifacts ???
     */
    initializeArtifacts(artifacts: Artifacts): JobCollection;
    /**
     * Calling `gcix.Job.addTags([...])` to all jobs within this JobCollection
     * that haven't been added tags before.
     * @param tags ???
     */
    initializeTags(tags: string[]): JobCollection;
    /**
     * Calling `gcix.Job.addTags([...])` to all jobs within this JobCollection
     * and overriding any previously added tags to that jobs.
     * @param tags ???
     */
    overrideTags(tags: string[]): JobCollection;
    /**
     * Calling `gcix.Job.append_rules()` to all jobs within this
     * JobCollection that haven't been added rules before.
     * @param rules ???
     */
    initializeRules(rules: Rule[]): JobCollection;
    /**
     * Calling `gcix.Job.overrideRules()` to all jobs within this
     * JobCollection and overriding any previously added rules to that jobs.
     * @param rules ???
     */
    overrideRules(rules: Rule[]): JobCollection;
    /**
     * Calling `gcix.Job.assignDependencies()` to all jobs within the
     * first stage of this JobCollection that haven't been added dependencies
     * before.
     *
     * An empty parameter list means that jobs will get an empty dependency
     * list and thus does not download artifacts by default.
     * @param dependencies ???
     */
    initializeDependencies(dependencies: (Job | JobCollection | Need)[]): JobCollection;
    /**
     * Calling `gcix.Job.assignDependencies()` to all jobs within the
     * first stage of this JobCollection and overriding any previously added
     * dependencies to that jobs.
     *
     * An empty parameter list means that jobs will get an empty dependency list
     * and thus does not download artifacts.
     * @param dependencies ???
     */
    overrideDependencies(dependencies: (Job | JobCollection | Need)[]): JobCollection;
    /**
     * Calling `gcix.Job.assignNeeds()` to all jobs within the first
     * stage of this JobCollection that haven't been added needs before.
     *
     * An empty parameter list means that jobs will get an empty dependency
     * list and thus does not depend on other jobs by default.
     * @param needs ???
     */
    initializeNeeds(needs: Array<Need | Job | JobCollection>): JobCollection;
    /**
     * Calling `gcix.Job.assignNeeds()` to all jobs within the first stage
     * of this JobCollection and overriding any previously added needs to that
     * jobs.
     *
     * An empty parameter list means that jobs will get an empty dependency list
     * and thus does not depend on other jobs.
     *
     * @param needs ???
     */
    overrideNeeds(needs: Array<Need | Job | JobCollection>): JobCollection;
    /**
     * Calling `gcix.Job.assignImage()` to all jobs within this JobCollection.
     * @param image ???
     */
    initializeImage(image: Image | string): JobCollection;
    /**
     * Calling `gcix.Job.assignImage()` to all jobs within this JobCollection
     * overriding any previous set value.
     * @param image ???
     */
    overrideImage(image: Image | string): JobCollection;
    /**
     * Calling `gcix.Job.assignAllowFailure()` to all jobs within this
     * JobCollection that haven't been set the allowFailure before.
     *
     * @param allowFailure ???
     * @returns the modified `JobCollection` object.
     */
    initializeAllowFailure(allowFailure: boolean | number[]): JobCollection;
    /**
     * Calling `gcix.Job.assignAllowFailure()` to all jobs within this
     * JobCollection overriding any previous set value.
     *
     * @param allowFailure ???
     * @returns the modified `JobCollection` object.
     */
    overrideAllowFailure(allowFailure: boolean | number[]): JobCollection;
    /**
     *
     * @param parent
     */
    addParent(parent: JobCollection): void;
}
/**
 * A JobCollection collects multiple `gcix.Job`s and/or other
 * `gcix.JobCollection`s into a group.
 */
export declare class JobCollection implements IJobCollection {
    parents: (Job | JobCollection)[];
    children: ChildDict[];
    allowFailureForInitialization?: string | boolean | number[];
    allowFailureForReplacement?: string | boolean | number[];
    variables?: Variables;
    variablesForInitialization?: Variables;
    variablesForReplacement?: Variables;
    cache?: Cache;
    cacheForInitialization?: Cache;
    artifacts?: Artifacts;
    artifactsForInitialization?: Artifacts;
    artifactsForReplacement?: Artifacts;
    orderedTags: OrderedStringSet;
    orderedTagsForInitialization: OrderedStringSet;
    orderedTagsForReplacement: OrderedStringSet;
    rulesToAppend?: Rule[];
    rulesToPrepend?: Rule[];
    rulesForInitialization?: Rule[];
    rulesForReplacement?: Rule[];
    dependencies?: (Job | JobCollection | Need)[];
    dependenciesForInitialization?: (Job | JobCollection | Need)[];
    dependenciesForReplacement?: (Job | JobCollection | Need)[];
    needs?: (Need | Job | JobCollection)[];
    needsForInitialization?: (Need | Job | JobCollection)[];
    needsForReplacement?: (Need | Job | JobCollection)[];
    scriptsToPrepend?: string[];
    scriptsToAppend?: string[];
    imageForInitialization?: Image | string;
    imageForReplacement?: Image | string;
    constructor();
    initializeAllowFailure(allowFailure: boolean | number[]): JobCollection;
    overrideAllowFailure(allowFailure: boolean | number[]): JobCollection;
    addVariables(variables: Variables): JobCollection;
    initializeVariables(variables: Variables): JobCollection;
    overrideVariables(variables: Variables): JobCollection;
    assignCache(cache: Cache): JobCollection;
    initializeCache(cache: Cache): JobCollection;
    assignArtifacts(artifacts: Artifacts): JobCollection;
    initializeArtifacts(artifacts: Artifacts): JobCollection;
    addTags(tags: string[]): JobCollection;
    initializeTags(tags: string[]): JobCollection;
    overrideTags(tags: string[]): JobCollection;
    appendRules(rules: Rule[]): JobCollection;
    prependRules(rules: Rule[]): JobCollection;
    initializeRules(rules: Rule[]): JobCollection;
    overrideRules(rules: Rule[]): JobCollection;
    addDependencies(dependencies: (Job | JobCollection | Need)[]): JobCollection;
    initializeDependencies(dependencies: (Job | JobCollection | Need)[]): JobCollection;
    overrideDependencies(dependencies: (Job | JobCollection | Need)[]): JobCollection;
    addNeeds(needs: (Job | JobCollection | Need)[]): JobCollection;
    initializeNeeds(needs: (Job | JobCollection | Need)[]): JobCollection;
    overrideNeeds(needs: (Job | JobCollection | Need)[]): JobCollection;
    prependScripts(scripts: string[]): JobCollection;
    appendScripts(scripts: string[]): JobCollection;
    initializeImage(image: string | Image): JobCollection;
    overrideImage(image: string | Image): JobCollection;
    addChildren(props: AddChildrenProps): JobCollection;
    getAllInstanceNames(child?: Job | JobCollection): OrderedStringSet;
    addParent(parent: JobCollection): void;
    get populatedJobs(): Job[];
    get lastJobsExecuted(): Job[];
    get nestedJobs(): Job[];
    render(): any;
    isEqual(comparable: IBase): comparable is IBase;
}
