/**
 * This module contains constants for [Gitlab CI predefined variables](https://docs.gitlab.com/ee/ci/variables/predefined_variables.html)
 */
/**
 * This proxy delays the operating system query for environment variables
 * until the value is requested.
 *
 * This proxy is designed for requesting predefined environment variables that
 * must exist within a Gitlab CI pipeline execution. Create an object from
 * this proxy with the name of the Gitlab `CI_*` variable you want to query:
 * ```
 * CI_COMMIT_REF_SLUG = EnvProxy("CI_COMMIT_REF_SLUG")  # process.env.CI_* is
 * not! called here
 * ```
 *
 * When using an object of this proxy in a statement it returns the value of
 * the `CI_*` variable requested or throws an `Error` if against our
 * expectations the variable is not available.
 *
 * ```
 * if CI_COMMIT_REF_SLUG == "foobar":  # <- process.env.CI_* is called here
 * ```
 *
 * The proxy has a different behavior when not being called within a Gitlab CI
 * pipeline execution. This is, when the environment variable `CI` is
 * unset (from the official Gitlab CI docs). Then the proxy does not raise a
 * KeyError for `CI_*` variables, because they naturally does not exist
 * (or at least their existence is not guaranteed). So if we are not running
 * within a Gitlab CI pipeline, the proxy insteads returns the dummy string
 * `notRunningInAPipeline` for all `CI_*` variables. Except for the `CI`
 * variable itself, where an empty string is returned, indicating we are not
 * running within a pipeline.
 *
 * @param key The name of the environment variable that should be queried on request.
 * @returns The value of the queried environment variable.
 */
export declare function EnvProxy(key: string): string;
export declare function OptionalEnvProxy(key: string): string | undefined;
/**
 * This class contains constants for [Gitlab CI predefined variables](https://docs.gitlab.com/ee/ci/variables/predefined_variables.html)
 */
export declare class PredefinedVariables {
    /**
     * Source chat channel which triggered the ChatOps command.
     *
     * Added in GitLab 10.6
     * Available in GitLab Runner all
     */
    static get chatChannel(): string;
    /**
     * Additional arguments passed in the ChatOps command.
     *
     * Added in GitLab 10.6
     * Available in GitLab Runner all
     */
    static get chatInput(): string;
    /**
     * Mark that job is executed in CI environment.
     *
     * Added in GitLab all
     * Available in GitLab Runner 0.4
     */
    static get ci(): string;
    /**
     * The GitLab API v4 root URL.
     *
     * Added in GitLab 11.7
     * Available in GitLab Runner all
     */
    static get ciApiV4Url(): string;
    /**
     * Top-level directory where builds are executed.
     *
     * Added in GitLab all
     * Available in GitLab Runner 11.10
     */
    static get ciBuildsDir(): string;
    /**
     * The previous latest commit present on a branch. Is always
     * 0000000000000000000000000000000000000000 in pipelines for merge requests.
     *
     * Added in GitLab 11.2
     * Available in GitLab Runner all
     */
    static get ciCommitBeforeSha(): string;
    /**
     * The description of the commit the message without first line,
     * if the title is shorter than 100 characters; full message in other case.
     *
     * Added in GitLab 10.8
     * Available in GitLab Runner all
     */
    static get ciCommitDescription(): string;
    /**
     * The full commit message.
     *
     * Added in GitLab 10.8
     * Available in GitLab Runner all
     */
    static get ciCommitMessage(): string;
    /**
     * The branch or tag name for which project is built.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciCommitRefName(): string;
    /**
     * true if the job is running on a protected reference, false if not.
     *
     * Added in GitLab 11.11
     * Available in GitLab Runner all
     */
    static get ciCommitRefProtected(): string;
    /**
     * $CI_COMMIT_REF_NAME in lowercase, shortened to 63 bytes,
     * and with everything except 0-9 and a-z replaced with -.
     * No leading / trailing -. Use in URLs, host names and domain names.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciCommitRefSlug(): string;
    /**
     * The commit revision for which project is built.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciCommitSha(): string;
    /**
     * The first eight characters of CI_COMMIT_SHA.
     *
     * Added in GitLab 11.7
     * Available in GitLab Runner all
     */
    static get ciCommitShortSha(): string;
    /**
     * The commit branch name. Present in branch pipelines,
     * including pipelines for the default branch.
     * Not present in merge request pipelines or tag pipelines.
     *
     * Added in GitLab 12.6
     * Available in GitLab Runner 0.5
     */
    static get ciCommitBranch(): string | undefined;
    /**
     * The commit tag name. Present only when building tags.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner 0.5
     */
    static get ciCommitTag(): string | undefined;
    /**
     * The title of the commit - the full first line of the message.
     *
     * Added in GitLab 10.8
     * Available in GitLab Runner all
     */
    static get ciCommitTitle(): string;
    /**
     * The timestamp of the commit in the ISO 8601 format.
     *
     * Added in GitLab 13.4
     * Available in GitLab Runner all
     */
    static get ciCommitTimestamp(): string;
    /**
     * Unique ID of build execution in a single executor.
     *
     * Added in GitLab all
     * Available in GitLab Runner 11.10
     */
    static get ciConcurrentId(): string;
    /**
     * Unique ID of build execution in a single executor and project.
     *
     * Added in GitLab all
     * Available in GitLab Runner 11.10
     */
    static get ciConcurrentProjectId(): string;
    /**
     * The path to CI configuration file. Defaults to .gitlab-ci.yml.
     *
     * Added in GitLab 9.4
     * Available in GitLab Runner 0.5
     */
    static get ciConfigPath(): string;
    /**
     * Whether debug logging (tracing) is enabled.
     *
     * Added in GitLab all
     * Available in GitLab Runner 1.7
     */
    static get ciDebugTrace(): string;
    /**
     * The name of the default branch for the project.
     *
     * Added in GitLab 12.4
     * Available in GitLab Runner all
     */
    static get ciDefaultBranch(): string;
    /**
     * The image prefix for pulling images through the Dependency Proxy.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciDependencyProxyGroupImagePrefix(): string;
    /**
     * The server for logging in to the Dependency Proxy. This is equivalent to $CI_SERVER_HOST:$CI_SERVER_PORT.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciDependencyProxyServer(): string;
    /**
     * The password to use to pull images through the Dependency Proxy.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciDependencyProxyPassword(): string;
    /**
     * The username to use to pull images through the Dependency Proxy.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciDependencyProxyUser(): string;
    /**
     * Included with the value true if the pipeline runs during a deploy freeze window.
     *
     * Added in GitLab 13.2
     * Available in GitLab Runner all
     */
    static get ciDeployFreeze(): string | undefined;
    /**
     * Authentication password of the GitLab Deploy Token,
     * only present if the Project has one related.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 10.8
     * Available in GitLab Runner all
     */
    static get ciDeployPassword(): string;
    /**
     * Authentication username of the GitLab Deploy Token,
     * only present if the Project has one related.
     *
     * Added in GitLab 10.8
     * Available in GitLab Runner all
     */
    static get ciDeployUser(): string;
    /**
     * Marks that the job is executed in a disposable environment
     * (something that is created only for this job and disposed of/destroyed
     * after the execution - all executors except shell and ssh).
     * If the environment is disposable, it is set to true,
     * otherwise it is not defined at all.
     *
     * Added in GitLab all
     * Available in GitLab Runner 10.1
     */
    static get ciDisposableEnvironment(): string | undefined;
    /**
     * The name of the environment for this job.
     * Only present if environment:name is set.
     *
     * Added in GitLab 8.15
     * Available in GitLab Runner all
     */
    static get ciEnvironmentName(): string | undefined;
    /**
     * A simplified version of the environment name,
     * suitable for inclusion in DNS, URLs, Kubernetes labels, and so on.
     * Only present if environment:name is set.
     *
     * Added in GitLab 8.15
     * Available in GitLab Runner all
     */
    static get ciEnvironmentSlug(): string | undefined;
    /**
     * The URL of the environment for this job.
     * Only present if environment:url is set.
     *
     * Added in GitLab 9.3
     * Available in GitLab Runner all
     */
    static get ciEnvironmentUrl(): string | undefined;
    /**
     * Pull Request ID from GitHub if the pipelines are for
     * external pull requests.
     * Available only if only [external_pull_requests] or
     * rules syntax is used and the pull request is open.
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestIid(): string | undefined;
    /**
     * The source repository name of the pull request if the pipelines are
     * for external pull requests. Available only if only
     * [external_pull_requests] or rules syntax is used and
     * the pull request is open.
     *
     * Added in GitLab 13.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestSourceRepository(): string | undefined;
    /**
     * The target repository name of the pull request if the pipelines
     * are for external pull requests. Available only if only
     * [external_pull_requests] or rules syntax is used and the pull
     * request is open.
     *
     * Added in GitLab 13.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestTargetRepository(): string | undefined;
    /**
     * The source branch name of the pull request if the pipelines are for
     * external pull requests. Available only if only [external_pull_requests]
     * or rules syntax is used and the pull request is open.
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestSourceBranchName(): string | undefined;
    /**
     * The HEAD SHA of the source branch of the pull request if the pipelines
     * are for external pull requests. Available only if only
     * [external_pull_requests] or rules syntax is used and the pull
     * request is open.
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestSourceBranchSha(): string | undefined;
    /**
     * The target branch name of the pull request if the pipelines are for
     * external pull requests. Available only if only [external_pull_requests]
     * or rules syntax is used and the pull request is open.
     *   *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestTargetBranchName(): string | undefined;
    /**
     * The HEAD SHA of the target branch of the pull request if the pipelines
     * are for external pull requests. Available only if only
     * [external_pull_requests] or rules syntax is used and the pull
     * request is open.
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciExternalPullRequestTargetBranchSha(): string | undefined;
    /**
     * Included with the value true only if the pipeline’s project has any
     * open requirements. Not included if there are no open requirements for
     * the pipeline’s project.
     *
     * Added in GitLab 13.1
     * Available in GitLab Runner all
     */
    static get ciHasOpenRequirements(): string | undefined;
    /**
     * Available in branch and merge request pipelines. Contains a
     * comma-separated list of up to four merge requests that use the current
     * branch and project as the merge request source.
     * For example gitlab-org/gitlab!333,gitlab-org/gitlab-foss!11.
     *
     * Added in GitLab 13.8
     * Available in GitLab Runner all
     */
    static get ciOpenMergeRequests(): string | undefined;
    /**
     * The unique ID of the current job that GitLab CI/CD uses internally.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciJobId(): string;
    /**
     * The name of the image running the CI job.
     *
     * Added in GitLab 12.9
     * Available in GitLab Runner 12.9
     */
    static get ciJobImage(): string;
    /**
     * The flag to indicate that job was manually started.
     *
     * Added in GitLab 8.12
     * Available in GitLab Runner all
     */
    static get ciJobManual(): string;
    /**
     * The name of the job as defined in .gitlab-ci.yml.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner 0.5
     */
    static get ciJobName(): string;
    /**
     * The name of the stage as defined in .gitlab-ci.yml.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner 0.5
     */
    static get ciJobStage(): string;
    /**
     * The state of the job as each runner stage is executed.
     * Use with after_script where CI_JOB_STATUS can be either success,
     * failed or canceled.
     *
     * Added in GitLab all
     * Available in GitLab Runner 13.5
     */
    static get ciJobStatus(): string;
    /**
     * Token used for authenticating with a few API endpoints and downloading
     * dependent repositories. The token is valid as long as the job is running.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner 1.2
     */
    static get ciJobToken(): string;
    /**
     * RS256 JSON web token that can be used for authenticating with third
     * party systems that support JWT authentication, for example HashiCorp’s Vault.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 12.10
     * Available in GitLab Runner all
     */
    static get ciJobJwt(): string;
    /**
     * Job details URL.
     *
     * Added in GitLab 11.1
     * Available in GitLab Runner 0.5
     */
    static get ciJobUrl(): string;
    /**
     * Included with the value true only if the pipeline has a Kubernetes
     * cluster available for deployments. Not included if no cluster is available.
     * Can be used as an alternative to only:kubernetes/except:kubernetes
     * with rules:if.
     *
     * Added in GitLab 13.0
     * Available in GitLab Runner all
     */
    static get ciKubernetesActive(): string | undefined;
    /**
     * Comma-separated list of username(s) of assignee(s) for the merge request
     * if the pipelines are for merge requests.
     * Available only if only [merge_requests] or rules syntax is used and the
     * merge request is created.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestAssignees(): string | undefined;
    /**
     * The instance-level ID of the merge request. Only available if the
     * pipelines are for merge requests and the merge request is created.
     * This is a unique ID across all projects on GitLab.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestId(): string | undefined;
    /**
     * The project-level IID (internal ID) of the merge request.
     * Only available If the pipelines are for merge requests and the merge
     * request is created. This ID is unique for the current project.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestIid(): string | undefined;
    /**
     * Comma-separated label names of the merge request if the pipelines are
     * for merge requests. Available only if only [merge_requests] or rules
     * syntax is used and the merge request is created.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestLabels(): string | undefined;
    /**
     * The milestone title of the merge request if the pipelines are for merge
     * requests. Available only if only [merge_requests] or rules syntax is
     * used and the merge request is created.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestMilestone(): string | undefined;
    /**
     * The ID of the project of the merge request if the pipelines are for
     * merge requests. Available only if only [merge_requests] or rules syntax
     * is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestProjectId(): string | undefined;
    /**
     * The path of the project of the merge request if the pipelines are for
     * merge requests (for example stage/awesome-project). Available only
     * if only [merge_requests] or rules syntax is used and the merge request
     * is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestProjectPath(): string | undefined;
    /**
     * The URL of the project of the merge request if the pipelines are for
     * merge requests (for example http://192.168.10.15:3000/stage/awesome-project).
     * Available only if only [merge_requests] or rules syntax is used and the merge
     * request is created.
     *   *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestProjectUrl(): string | undefined;
    /**
     * The ref path of the merge request if the pipelines are for merge requests.
     * (for example refs/merge-requests/1/head). Available only if only
     * [merge_requests] or rules syntax is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestRefPath(): string | undefined;
    /**
     * The source branch name of the merge request if the pipelines are for
     * merge requests. Available only if only [merge_requests] or rules syntax
     * is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestSourceBranchName(): string | undefined;
    /**
     * The HEAD SHA of the source branch of the merge request if the pipelines
     * are for merge requests. Available only if only [merge_requests] or rules
     * syntax is used, the merge request is created, and the pipeline is a
     * merged result pipeline.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestSourceBranchSha(): string | undefined;
    /**
     * The ID of the source project of the merge request if the pipelines are
     * for merge requests. Available only if only [merge_requests] or rules
     * syntax is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestSourceProjectId(): string | undefined;
    /**
     * The path of the source project of the merge request if the pipelines
     * are for merge requests. Available only if only [merge_requests] or
     * rules syntax is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestSourceProjectPath(): string | undefined;
    /**
     * The URL of the source project of the merge request if the pipelines are
     * for merge requests. Available only if only [merge_requests] or rules
     * syntax is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestSourceProjectUrl(): string | undefined;
    /**
     * The target branch name of the merge request if the pipelines are for
     * merge requests. Available only if only [merge_requests] or rules syntax
     * is used and the merge request is created.
     *
     * Added in GitLab 11.6
     * Available in GitLab Runner all
     */
    static get ciMergeRequestTargetBranchName(): string;
    /**
     * The HEAD SHA of the target branch of the merge request if the pipelines
     * are for merge requests. Available only if only [merge_requests] or rules
     * syntax is used, the merge request is created, and the pipeline is a merged
     * result pipeline.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestTargetBranchSha(): string;
    /**
     * The title of the merge request if the pipelines are for merge requests.
     * Available only if only [merge_requests] or rules syntax is used and the
     * merge request is created.
     *
     * Added in GitLab 11.9
     * Available in GitLab Runner all
     */
    static get ciMergeRequestTitle(): string | undefined;
    /**
     * The event type of the merge request, if the pipelines are for merge requests.
     * Can be detached, merged_result or merge_train.
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciMergeRequestEventType(): string | undefined;
    /**
     * The version of the merge request diff, if the pipelines are for merge requests.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciMergeRequestDiffId(): string | undefined;
    /**
     * The base SHA of the merge request diff, if the pipelines are for merge requests.
     *
     * Added in GitLab 13.7
     * Available in GitLab Runner all
     */
    static get ciMergeRequestDiffBaseSha(): string | undefined;
    /**
     * Index of the job in the job set. If the job is not parallelized, this variable is not set.
     *
     * Added in GitLab 11.5
     * Available in GitLab Runner all
     */
    static get ciNodeIndex(): string | undefined;
    /**
     * Total number of instances of this job running in parallel. If the job is not parallelized, this variable is set to 1.
     *
     * Added in GitLab 11.5
     * Available in GitLab Runner all
     */
    static get ciNodeTotal(): string;
    /**
     * The configured domain that hosts GitLab Pages.
     *
     * Added in GitLab 11.8
     * Available in GitLab Runner all
     */
    static get ciPagesDomain(): string;
    /**
     * URL to GitLab Pages-built pages. Always belongs to a subdomain of CI_PAGES_DOMAIN.
     *
     * Added in GitLab 11.8
     * Available in GitLab Runner all
     */
    static get ciPagesUrl(): string;
    /**
     * The instance-level ID of the current pipeline. This is a unique ID
     * across all projects on GitLab.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner all
     */
    static get ciPipelineId(): string;
    /**
     * The project-level IID (internal ID) of the current pipeline.
     * This ID is unique for the current project.
     *
     * Added in GitLab 11.0
     * Available in GitLab Runner all
     */
    static get ciPipelineIid(): string;
    /**
     * Indicates how the pipeline was triggered.
     * Possible options are push, web, schedule, api, external, chat, webide,
     * merge_request_event, external_pull_request_event, parent_pipeline,
     * trigger, or pipeline.
     * For pipelines created before GitLab 9.5, this is displayed as unknown.
     *
     * Added in GitLab 10.0
     * Available in GitLab Runner all
     */
    static get ciPipelineSource(): string;
    /**
     * The flag to indicate that job was triggered.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciPipelineTriggered(): string;
    /**
     * Pipeline details URL.
     *
     * Added in GitLab 11.1
     * Available in GitLab Runner 0.5
     */
    static get ciPipelineUrl(): string;
    /**
     * The CI configuration path for the project.
     *
     * Added in GitLab 13.8
     * Available in GitLab Runner all
     */
    static get ciProjectConfigPath(): string;
    /**
     * The full path where the repository is cloned and where the job is run.
     * If the GitLab Runner builds_dir parameter is set, this variable is set
     * relative to the value of builds_dir. For more information, see Advanced
     * configuration for GitLab Runner.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciProjectDir(): string;
    /**
     * The unique ID of the current project that GitLab CI/CD uses internally.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciProjectId(): string;
    /**
     * The name of the directory for the project that is being built.
     * For example, if the project URL is gitlab.example.com/group-name/project-1,
     * the CI_PROJECT_NAME would be project-1.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciProjectName(): string;
    /**
     * The project stage (username or group name) that is being built.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciProjectNamespace(): string;
    /**
     * The root project stage (username or group name) that is being built.
     * For example, if CI_PROJECT_NAMESPACE is root-group/child-group/grandchild-group,
     * CI_PROJECT_ROOT_NAMESPACE would be root-group.
     *
     * Added in GitLab 13.2
     * Available in GitLab Runner 0.5
     */
    static get ciProjectRootNamespace(): string;
    /**
     * The stage with project name.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciProjectPath(): string;
    /**
     * $CI_PROJECT_PATH in lowercase and with everything except 0-9 and a-z replaced with -. Use in URLs and domain names.
     *
     * Added in GitLab 9.3
     * Available in GitLab Runner all
     */
    static get ciProjectPathSlug(): string;
    /**
     * Comma-separated, lowercase list of the languages used in the repository (for example ruby,javascript,html,css).
     *
     * Added in GitLab 12.3
     * Available in GitLab Runner all
     */
    static get ciProjectRepositoryLanguages(): string;
    /**
     * The human-readable project name as displayed in the GitLab web interface.
     *
     * Added in GitLab 12.4
     * Available in GitLab Runner all
     */
    static get ciProjectTitle(): string;
    /**
     * The HTTP(S) address to access project.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciProjectUrl(): string;
    /**
     * The project visibility (internal, private, public).
     *
     * Added in GitLab 10.3
     * Available in GitLab Runner all
     */
    static get ciProjectVisibility(): string;
    /**
     * GitLab Container Registry. This variable includes a :port value if one
     * has been specified in the registry configuration.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciRegistry(): string | undefined;
    /**
     * the address of the registry tied to the specific project.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciRegistryImage(): string | undefined;
    /**
     * The password to use to push containers to the GitLab Container Registry, for the current project.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciRegistryPassword(): string;
    /**
     * The username to use to push containers to the GitLab Container Registry, for the current project.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciRegistryUser(): string | undefined;
    /**
     * The URL to clone the Git repository.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab 9.0
     * Available in GitLab Runner all
     */
    static get ciRepositoryUrl(): string;
    /**
     * The description of the runner as saved in GitLab.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciRunnerDescription(): string;
    /**
     * The OS/architecture of the GitLab Runner executable (note that this is not necessarily the same as the environment of the executor).
     *
     * Added in GitLab all
     * Available in GitLab Runner 10.6
     */
    static get ciRunnerExecutableArch(): string;
    /**
     * The unique ID of runner being used.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciRunnerId(): string;
    /**
     * GitLab Runner revision that is executing the current job.
     *
     * Added in GitLab all
     * Available in GitLab Runner 10.6
     */
    static get ciRunnerRevision(): string;
    /**
     * First eight characters of the runner’s token used to authenticate new job requests. Used as the runner’s unique ID.
     *
     * ATTENTION: Contrary to most other variables in this class, this variable is not resolved at rendering
     * time. Instead the variable string is returned, which is then resolved during pipeline execution.
     * This is because the value contains sensitive information.
     *
     * Added in GitLab all
     * Available in GitLab Runner 12.3
     */
    static get ciRunnerShortToken(): string;
    /**
     * The defined runner tags.
     *
     * Added in GitLab 8.10
     * Available in GitLab Runner 0.5
     */
    static get ciRunnerTags(): string;
    /**
     * GitLab Runner version that is executing the current job.
     *
     * Added in GitLab all
     * Available in GitLab Runner 10.6
     */
    static get ciRunnerVersion(): string;
    /**
     * Mark that job is executed in CI environment.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciServer(): string;
    /**
     * The base URL of the GitLab instance, including protocol and port (like https://gitlab.example.com:8080).
     *
     * Added in GitLab 12.7
     * Available in GitLab Runner all
     */
    static get ciServerUrl(): string;
    /**
     * Host component of the GitLab instance URL, without protocol and port (like gitlab.example.com).
     *
     * Added in GitLab 12.1
     * Available in GitLab Runner all
     */
    static get ciServerHost(): string;
    /**
     * Port component of the GitLab instance URL, without host and protocol (like 3000).
     *
     * Added in GitLab 12.8
     * Available in GitLab Runner all
     */
    static get ciServerPort(): string;
    /**
     * Protocol component of the GitLab instance URL, without host and port (like https).
     *
     * Added in GitLab 12.8
     * Available in GitLab Runner all
     */
    static get ciServerProtocol(): string;
    /**
     * The name of CI server that is used to coordinate jobs.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciServerName(): string;
    /**
     * GitLab revision that is used to schedule jobs.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciServerRevision(): string;
    /**
     * GitLab version that is used to schedule jobs.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get ciServerVersion(): string;
    /**
     * GitLab version major component.
     *
     * Added in GitLab 11.4
     * Available in GitLab Runner all
     */
    static get ciServerVersionMajor(): string;
    /**
     * GitLab version minor component.
     *
     * Added in GitLab 11.4
     * Available in GitLab Runner all
     */
    static get ciServerVersionMinor(): string;
    /**
     * GitLab version patch component.
     *
     * Added in GitLab 11.4
     * Available in GitLab Runner all
     */
    static get ciServerVersionPatch(): string;
    /**
     * Marks that the job is executed in a shared environment (something that
     * is persisted across CI invocations like shell or ssh executor).
     * If the environment is shared, it is set to true, otherwise it is not
     * defined at all.
     *
     * Added in GitLab all
     * Available in GitLab Runner 10.1
     */
    static get ciSharedEnvironment(): string | undefined;
    /**
     * Mark that job is executed in GitLab CI/CD environment.
     *
     * Added in GitLab all
     * Available in GitLab Runner all
     */
    static get gitlabCi(): string;
    /**
     * The comma separated list of licensed features available for your instance and plan.
     *
     * Added in GitLab 10.6
     * Available in GitLab Runner all
     */
    static get gitlabFeatures(): string;
    /**
     * The email of the user who started the job.
     *
     * Added in GitLab 8.12
     * Available in GitLab Runner all
     */
    static get gitlabUserEmail(): string;
    /**
     * The ID of the user who started the job.
     *
     * Added in GitLab 8.12
     * Available in GitLab Runner all
     */
    static get gitlabUserId(): string;
    /**
     * The login username of the user who started the job.
     *
     * Added in GitLab 10.0
     * Available in GitLab Runner all
     */
    static get gitlabUserLogin(): string;
    /**
     * The real name of the user who started the job.
     *
     * Added in GitLab 10.0
     * Available in GitLab Runner all
     */
    static get gitlabUserName(): string;
    /**
     * This variable is available when a pipeline is triggered with a webhook
     *
     * Added in GitLab 13.9
     * Available in GitLab Runner all
     */
    static get triggerPayload(): string | undefined;
}
